==> 0.0.49.tar.gz: example/lib/Screen/ThemePickerScreen.dart <==
import 'package:bui_component/DrawerComonent/kfDrawer.dart';
import 'package:bui_component/ThemeComponent/ThemeColorComponent.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:example/Constants/AppColors.dart';

class ThemePickerScreen extends KFDrawerContent {
  Function() onBackPressed;

  ThemePickerScreen({this.onBackPressed});

  @override
  ThemePickerScreenState createState() => ThemePickerScreenState();
}

class ThemePickerScreenState extends State<ThemePickerScreen> {
  static bool isSelected = false;

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    getStringValuesSF();
    setState(() {
      isSelected = true;
    });
  }

  Color appbarColor = Colors.blueGrey;

  Color backgroundColor = AppColors.APP_COLOR_PRIMARY;

  Set<Color> swatches = Colors.primaries.map((e) => Color(e.value)).toSet();

  getStringValuesSF() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString('stringValue');

    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        backgroundColor = Color(colorCodeInt);
        this.mounted;
      });
    } else {
      backgroundColor = AppColors.APP_COLOR_PRIMARY;
    }
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () {
        onBackPressed();
      },
      child: ThemeColorComponent(
        onMenuPressed: onMenuPressed,
        onBackPressed: onBackPressed,
        backgroundColor: backgroundColor,
      ),
    );
  }

  Future<void> onBackPressed() async {
    widget.onBackPressed();
    Navigator.pop(context);
  }

  Future<void> onMenuPressed() async {
    setState(() {
      isSelected = true;
      getStringValuesSF();
      widget.onMenuPressed();
    });
  }
}

==> 0.0.50.tar.gz: example/lib/Screen/ThemePickerScreen.dart <==
import 'package:bui_component/DrawerComonent/kfDrawer.dart';
import 'package:bui_component/ThemeComponent/ThemeColorComponent.dart';
import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:example/Constants/AppColors.dart';
import 'package:example/Constants/AppStrings.dart';

class ThemePickerScreen extends KFDrawerContent {
  Function() onBackPressed;

  ThemePickerScreen({this.onBackPressed});

  @override
  ThemePickerScreenState createState() => ThemePickerScreenState();
}

class ThemePickerScreenState extends State<ThemePickerScreen> {
  static bool isSelected = false;

  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    getStringValuesSF();
    setState(() {
      isSelected = true;
    });
  }

  Color appbarColor = Colors.blueGrey;

  Color backgroundColor = AppColors.APP_COLOR_PRIMARY;
  Color secondaryColorTheme = AppColors.APP_COLOR_PRIMARY;

  Set<Color> swatches = Colors.primaries.map((e) => Color(e.value)).toSet();

  getStringValuesSF() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);
    String secondaryColor = prefs.getString(AppStrings.SECONDARY_THEME_COLOR);

    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);

      setState(() {
        backgroundColor = Color(colorCodeInt);
        this.mounted;
      });
    } else {
      backgroundColor = AppColors.APP_COLOR_PRIMARY;
    }

    if (secondaryColor != null) {
      int colorCodeInt = int.parse(secondaryColor);
      setState(() {
        secondaryColorTheme = Color(colorCodeInt);
        this.mounted;
      });
    } else {
      setState(() {
        secondaryColorTheme = AppColors.APP_COLOR_PRIMARY;
        this.mounted;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () {
        onBackPressed();
      },
      child: ThemeColorComponent(
        onMenuPressed: onMenuPressed,
        onBackPressed: onBackPressed,
        backgroundColor: backgroundColor,
        secondaryColor: secondaryColorTheme,
      ),
    );
  }

  Future<void> onBackPressed() async {
    widget.onBackPressed();
    Navigator.pop(context);
  }

  Future<void> onMenuPressed() async {
    setState(() {
      isSelected = true;
      getStringValuesSF();
      widget.onMenuPressed();
    });
  }
}
